/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#include "caosdb/info.h"
#include "caosdb/info/v1alpha1/main.pb.h" // for GetVersionInfoResponse

namespace caosdb::info {
using ProtoVersionInfo = caosdb::info::v1alpha1::VersionInfo;

VersionInfo::VersionInfo(ProtoVersionInfo *info) { this->info = info; }

[[nodiscard]] auto VersionInfo::GetMajor() const -> uint32_t {
  return this->info->major();
}

[[nodiscard]] auto VersionInfo::GetMinor() const -> uint32_t {
  return this->info->minor();
}

[[nodiscard]] auto VersionInfo::GetPatch() const -> uint32_t {
  return this->info->patch();
}

[[nodiscard]] auto VersionInfo::GetPreRelease() const -> const std::string & {
  return this->info->pre_release();
}

[[nodiscard]] auto VersionInfo::GetBuild() const -> const std::string & {
  return this->info->build();
}

} // namespace caosdb::info
